package com.koucky.petr.mysldenik;

import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.AuthResult;
import com.google.firebase.auth.FirebaseAuth;

public class SignUpActivity extends AppCompatActivity {

    private Button btnBack;
    private Button btnRegistrace;
    private EditText email;
    private EditText pass;
    private EditText passAgain;
    private ProgressBar progressBar;
    private FirebaseAuth auth;
    private EditText name;
    private TextView emailSentTitle;
    private TextView emailSentMsg;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        auth = FirebaseAuth.getInstance();
        setContentView(R.layout.activity_sign_up);

        btnBack = (Button) findViewById(R.id.btnBack);
        btnRegistrace = (Button) findViewById(R.id.btnRegistrace);
        email = (EditText) findViewById(R.id.email);
        pass = (EditText) findViewById(R.id.password);
        passAgain = (EditText) findViewById(R.id.passwordAgain);
        progressBar = (ProgressBar) findViewById(R.id.progressBar);
        name = (EditText) findViewById(R.id.name);
        emailSentMsg = (TextView) findViewById(R.id.emailSentMsg);
        emailSentTitle = (TextView) findViewById(R.id.emailSentTitle);

        btnBack.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                finish();
            }
        });

        btnRegistrace.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {

                String emailText = email.getText().toString().trim();
                String passText = pass.getText().toString().trim();
                String passAgainText = passAgain.getText().toString().trim();
                String nameText = name.getText().toString().trim();

                if (TextUtils.isEmpty(emailText)) {
                    Toast.makeText(SignUpActivity.this, getString(R.string.insertEmail), Toast.LENGTH_SHORT).show();
                    return;
                }

                if (TextUtils.isEmpty(nameText)) {
                    Toast.makeText(SignUpActivity.this, getString(R.string.insertName), Toast.LENGTH_SHORT).show();
                    return;
                }

                if (TextUtils.isEmpty(passText)) {
                    Toast.makeText(SignUpActivity.this, getString(R.string.insertPass), Toast.LENGTH_SHORT).show();
                    return;
                }

                if (passText.length() < 6) {
                    Toast.makeText(getApplicationContext(), getString(R.string.lengthPassError), Toast.LENGTH_SHORT).show();
                    return;
                }

                if (TextUtils.isEmpty(passAgainText)) {
                    Toast.makeText(SignUpActivity.this, getString(R.string.insertPassAgain), Toast.LENGTH_SHORT).show();
                    return;
                }

                if (!TextUtils.equals(passText, passAgainText)) {
                    Toast.makeText(SignUpActivity.this, getString(R.string.samePassError), Toast.LENGTH_SHORT).show();
                    return;
                }

                progressBar.setVisibility(View.VISIBLE);
                auth.createUserWithEmailAndPassword(emailText, passText)
                        .addOnCompleteListener(SignUpActivity.this, new OnCompleteListener<AuthResult>() {
                            @Override
                            public void onComplete(@NonNull Task<AuthResult> task) {
                                progressBar.setVisibility(View.GONE);
                                if (!task.isSuccessful()) {
                                    if (task.getException().getMessage().equals(getString(R.string.invalidEmailFormat))) {
                                        Toast.makeText(SignUpActivity.this, getString(R.string.invalidEmailFormatError),
                                                Toast.LENGTH_SHORT).show();
                                    }

                                    if (task.getException().getMessage().equals(getString(R.string.alreadyUsedEmail))) {
                                        Toast.makeText(SignUpActivity.this, getString(R.string.alreadyUsedEmailError),
                                                Toast.LENGTH_SHORT).show();
                                    }


                                } else {
                                    task.getResult().getUser().sendEmailVerification();
                                    btnRegistrace.setVisibility(View.GONE);
                                    email.setVisibility(View.GONE);
                                    pass.setVisibility(View.GONE);
                                    passAgain.setVisibility(View.GONE);
                                    progressBar.setVisibility(View.GONE);
                                    name.setVisibility(View.GONE);
                                    emailSentMsg.setVisibility(View.VISIBLE);
                                    emailSentTitle.setVisibility(View.VISIBLE);
                                }
                            }
                        });

            }

        });

    }


}
